@@ -1,6 +1,7 @@
 import datetime as dt
 import openpyxl as xl
 import pandas as pd
+import sys
 import os
 
 from google.cloud.bigquery import Client, TableReference
@@ -275,11 +276,12 @@ def delete_bq_tables(start_date: str, end_date: str, interval_type: str, interva
 
     if bq_key_path is None:
         log("bq_key_path not provided searching working directory")
-        bq_key_path = os.getcwd()
+        directory_name, file_name = os.path.split(os.path.abspath(sys.modules['__main__'].__file__))
+        bq_key_path = directory_name
         bq_full_key_path = os.path.join(bq_key_path, bq_key_name)
 
     else:
-        bq_full_key_path = bq_key_path + bq_key_path
+        bq_full_key_path = bq_key_path + bq_key_name
 
     scopes = ['https://www.googleapis.com/auth/bigquery', 'https://www.googleapis.com/auth/drive.readonly']
     credentials = service_account.Credentials.from_service_account_file(bq_full_key_path, scopes=scopes)
